@@ -167,6 +167,51 @@ protected :
     int64u Speed_Contains_NULL;                         //Per Frame - Error 4
     int64u Speed_FrameCount_Arb_Incoherency;            //Global    - Error 5
     int64u Speed_FrameCount_Stts_Fluctuation;           //Global    - Error 6
+    struct abst_bf
+    {
+        struct value_trust
+        {
+            int32s Value;
+            int32s Trust;
+
+            value_trust()
+            {
+                Value=0;
+                Trust=0;
+            }
+
+            bool operator < (const value_trust& b) const
+            {
+                if (Trust==b.Trust)
+                    return Value<b.Value;
+                return Trust>b.Trust;
+            }
+        };
+        vector<value_trust> abst[2]; //0=standard, 1=non-standard x1.5
+        set<int32s> StoredValues;
+        size_t bf[2];
+        size_t Frames_NonStandard[2]; //0=x0.5, 1=x1.5
+
+        abst_bf()
+        {
+            Frames_NonStandard[0]=0;
+            Frames_NonStandard[1]=0;
+            reset();
+        }
+
+        void reset()
+        {
+            abst[0].clear();
+            abst[1].clear();
+            bf[0]=0;
+            bf[1]=0;
+            StoredValues.clear();
+        }
+    };
+    abst_bf AbstBf_Current_Weighted;
+    int32u AbstBf_Current;
+    int32u AbstBf_Previous;
+    int32s AbstBf_Previous_MaxAbst;
     int8u  SMP;
     int8u  QU;
     bool   QU_FSC; //Validity is with QU
@@ -243,14 +288,17 @@ protected :
     std::vector<size_t> Video_STA_Errors_Total; //Per STA type
     static const size_t ChannelGroup_Count=2;
     static const size_t Dseq_Count=16;
+    enum caption
+    {
+        Caption_Present,
+        Caption_ParityIssueAny,
+    };
     bitset<32> Captions_Flags;
     enum coherency
     {
         Coherency_PackInSub,
         Coherency_PackInVid,
         Coherency_PackInAud,
-        Coherency_DataInVid,
-        Coherency_DataInAud,
         Coherency_video_source,
         Coherency_video_control,
         Coherency_audio_source,
@@ -313,7 +361,14 @@ protected :
     };
     std::vector<timeStampsZ> Speed_TimeStampsZ;
 
-
+    enum status
+    {
+        BlockStatus_Unk,
+        BlockStatus_OK,
+        BlockStatus_NOK,
+    };
+    static const size_t BlockStatus_MaxSize=1800*4; // Max 1800 if PAL * 4 if DV100
+    MediaInfo_int8u BlockStatus[BlockStatus_MaxSize];
 
     struct arb
     {
