@@ -121,6 +121,7 @@ File_Riff::File_Riff()
     SMV_BlockSize=0;
     SamplesPerSec=0;
     stream_Count=0;
+    AdmProfile_Dolby=0;
     BlockAlign=0;
     rec__Present=false;
     NeedOldIndex=true;
@@ -177,6 +178,17 @@ void File_Riff::Streams_Finish ()
     //Global
     if (IsRIFF64)
         Fill(Stream_General, 0, General_Format_Profile, "RF64");
+    if ((AdmProfile_Dolby&3)==3)
+    {
+        Fill(Stream_Audio, 0, "AdmProfile", (AdmProfile_Dolby&4)?"Dolby Atmos Master, Version 1":"Dolby Atmos Master");
+        Fill(Stream_Audio, 0, "AdmProfile_Format", "Dolby Atmos Master");
+        Fill_SetOptions(Stream_Audio, 0, "AdmProfile_Format", "N NTY");
+        if (AdmProfile_Dolby&4)
+        {
+            Fill(Stream_Audio, 0, "AdmProfile_Version", "1");
+            Fill_SetOptions(Stream_Audio, 0, "AdmProfile_Version", "N NTY");
+        }
+    }
 
     //Time codes
     TimeCode_Fill(__T("ISMP"), INFO_ISMP);
@@ -925,31 +937,8 @@ void File_Riff::Header_Parse()
     if (IsBigEndian)
         Get_B4 (Size,                                           "Size");
     else
-    {
         Get_L4 (Size,                                           "Size");
 
-        //Testing malformed (not word aligned)
-        if (!IsNotWordAligned_Tested && Size%2)
-        {
-            if (File_Offset+Buffer_Offset+8+Size==File_Size)
-                IsNotWordAligned=true;
-            #if defined(MEDIAINFO_FILE_YES) //TODO: seek if file API is not available
-            else if (!File_Name.empty())
-            {
-                File F(File_Name);
-                F.GoTo(File_Offset+Buffer_Offset+8+Size);
-                int8u Temp;
-                if (F.Read(&Temp, 1))
-                {
-                    if (!((Temp<'A' || Temp>'z') && Temp!=' '))
-                        IsNotWordAligned=true;
-                }
-            }
-            #endif //defined(MEDIAINFO_FILE_YES)
-            IsNotWordAligned_Tested=true;
-        }
-    }
-
     //RF64
     int64u Size_Complete=Size;
     if (Size==0 && Name==Elements::RIFF)
@@ -973,6 +962,27 @@ void File_Riff::Header_Parse()
         }
     }
 
+    //Testing malformed (not word aligned)
+    if (!IsNotWordAligned_Tested && !IsBigEndian && Size_Complete %2)
+    {
+        if (File_Offset+Buffer_Offset+8+Size_Complete==File_Size)
+            IsNotWordAligned=true;
+        #if defined(MEDIAINFO_FILE_YES) //TODO: seek if file API is not available
+        else if (!File_Name.empty())
+        {
+            File F(File_Name);
+            F.GoTo(File_Offset+Buffer_Offset+8+Size);
+            int8u Temp;
+            if (F.Read(&Temp, 1))
+            {
+                if (!((Temp<'A' || Temp>'z') && Temp!=' '))
+                    IsNotWordAligned=true;
+            }
+        }
+        #endif //defined(MEDIAINFO_FILE_YES)
+        IsNotWordAligned_Tested=true;
+    }
+
     //Coherency
     if (Stream_Structure_Temp!=Stream_Structure.end() && Stream_Structure_Temp->second.Size==0)
     {
